"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const node_fetch_1 = __importDefault(require("node-fetch"));
const fs_1 = __importDefault(require("fs"));
const path_1 = __importDefault(require("path"));
const util_1 = require("./util");
const filenamify_1 = __importDefault(require("filenamify"));
const headers_1 = require("./headers");
const generate = (params) => __awaiter(void 0, void 0, void 0, function* () {
    let { output, cookie, time, id } = params;
    let writeStream;
    output = path_1.default.resolve(output);
    if (!util_1.fsExistsSync(output)) {
        console.log("输出目录不存在，正在创建...");
        fs_1.default.mkdirSync(output);
    }
    try {
        const res = yield node_fetch_1.default(`https://blog-console-api.csdn.net/v1/editor/getArticle?id=${id}`, {
            headers: Object.assign({ cookie: cookie }, headers_1.headers),
        });
        const { data, code, msg } = yield res.json();
        if (code !== 200) {
            console.log(code, msg);
            return;
        }
        const { markdowncontent, content, tags: tagsStr, categories: categoriesStr, title, } = data;
        let tags = []; //标签
        let categories = []; //分类
        if (tagsStr && tagsStr.length > 0) {
            tags = tagsStr.split(",");
        }
        if (categoriesStr && categoriesStr.length > 0) {
            categories = categoriesStr.split(",");
        }
        writeStream = fs_1.default.createWriteStream(path_1.default.join(output, `./${filenamify_1.default(title)}.md`), "utf8");
        console.log("生成", title);
        writeStream.write("---\n");
        writeStream.write(`title: ${title}\n`);
        writeStream.write(`date: ${time}\n`);
        writeStream.write(`tags: ${tags.join(" ")}\n`);
        writeStream.write(`categories: ${categories.join(" ")}\n`);
        writeStream.write("---\n\n");
        writeStream.write("<!--more-->\n\n");
        writeStream.write(markdowncontent || content || "");
        writeStream.end("");
    }
    catch (e) {
        console.log(`出错: ${id}`, e);
    }
    finally {
        writeStream.close();
    }
});
exports.default = generate;
//# sourceMappingURL=generateByApi.js.map